Help make Dataspectra better
^^^^^^^^^^^^^^^^^^^^^^^^^^^^

Dataspectra is open source, and we encourage you
to help make it better. You don't need to know how to
code to help. 


Ways to contribute
==================

- Improve the documentation
- Design more themes
- Code more themes
- Create a web interface for creating parameter files 
- Create more flexibility in the plotting
- Create more figure types
- Create more examples
- Coding test functions
- Clean and document the code

How to contribute
=================
-  Tweet theme design ideas to: 
-  Contribute code to github: 



